@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
 import os
-import time
 
-from subprocess import Popen
+from subprocess import call
 from .logger import log
 
 
@@ -19,11 +18,9 @@ class Runner(object):
 
     def _print_execution_header(self):
         log.info(
-            "\n\n\n" +
-            "".ljust(40, '-').rjust(80, '-') +
-            "\n{}\n".format('PYTEST EXECUTION'.ljust(40).rjust(80)) +
-            "".ljust(40, '-').rjust(80, '-') +
-            "\n\n\n"
+            "\n" * 3 + "".center(80, '-') + "\n" +
+            "TEST EXECUTION".center(80, ' ') +
+            "\n" + "".center(80, '-') + "\n" * 3
         )
 
     def _execute_tests(self, project_path, test_path="2222"):
@@ -32,15 +29,7 @@ class Runner(object):
             return -1
         os.chdir(project_path)
         cmd = "cd {}; {} {} {}".format(project_path, self._tester_cmd, self._tester_args, test_path)
-        proc = Popen(cmd, shell=True)
-        return self._wait_until_execution_result(proc)
-
-    def _wait_until_execution_result(self, proc):
-        result = None
-        while result is None:
-            result = proc.poll()
-            time.sleep(.1)
-        return result
+        return call(cmd, shell=True)
 
     def _call_notifier(self, name, result):
         if result == 0:
